==> dcl-c_5.3-1.tar.gz: dcl-c-5.3/src/grph1/slpack/slqrct.c <==
/* src/grph1/slpack/slqrct.f -- translated by f2c (version 20020621).
   You must link the resulting object file with the libraries:
	-lf2c -lm   (in that order)
*/

#include "libtinyf2c.h"

/* Common Block Declarations */

struct {
    real xmin[40], xmax[40], ymin[40], ymax[40];
    integer nn[4];
} slblk1_;

#define slblk1_1 slblk1_

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int slqrct_(integer *lev, integer *ifrm, real *xamin, real *
	xamax, real *yamin, real *yamax)
{
    static integer nm, levc, jfrm;
    extern integer isum0_(integer *, integer *, integer *);
    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), msgdmp_(
	    char *, char *, char *, ftnlen, ftnlen, ftnlen);

    sgiget_("NLEVEL", &levc, (ftnlen)6);
    if (! (0 <= *lev && *lev <= levc)) {
	msgdmp_("E", "SLQRCT", "LEVEL NUMBER IS INVALID.", (ftnlen)1, (ftnlen)
		6, (ftnlen)24);
    }
    if (*ifrm <= 0) {
	msgdmp_("E", "SLQRCT", "FRAME NUMBER IS LESS THAN ZERO.", (ftnlen)1, (
		ftnlen)6, (ftnlen)31);
    }
    jfrm = (*ifrm - 1) % slblk1_1.nn[*lev] + 1;
    nm = jfrm + isum0_(slblk1_1.nn, lev, &c__1);
    *xamin = slblk1_1.xmin[nm - 1];
    *xamax = slblk1_1.xmax[nm - 1];
    *yamin = slblk1_1.ymin[nm - 1];
    *yamax = slblk1_1.ymax[nm - 1];
    return 0;
} /* slqrct_ */

==> dcl-c_5.3.3.orig.tar.gz: dcl-c-5.3.3/src/grph1/slpack/slqrct.c <==
/*  -- translated by f2c (version 20050501).
   You must link the resulting object file with libf2c:
	on Microsoft Windows system, link with libf2c.lib;
	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
	or, if you install libf2c.a in a standard place, with -lf2c -lm
	-- in that order, at the end of the command line, as in
		cc *.o -lf2c -lm
	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,

		http://www.netlib.org/f2c/libf2c.zip
*/

#include "libtinyf2c.h"

/* Common Block Declarations */

struct {
    real xmin[40], xmax[40], ymin[40], ymax[40];
    integer nn[4];
} slblk1_;

#define slblk1_1 slblk1_

/* Table of constant values */

static integer c__1 = 1;

/* ----------------------------------------------------------------------- */
/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
/* ----------------------------------------------------------------------- */
/* Subroutine */ int slqrct_(integer *lev, integer *ifrm, real *xamin, real *
	xamax, real *yamin, real *yamax)
{
    static integer nm, levc, jfrm;
    extern integer isum0_(integer *, integer *, integer *);
    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), msgdmp_(
	    char *, char *, char *, ftnlen, ftnlen, ftnlen);

    sgiget_("NLEVEL", &levc, (ftnlen)6);
    if (! (0 <= *lev && *lev <= levc)) {
	msgdmp_("E", "SLQRCT", "LEVEL NUMBER IS INVALID.", (ftnlen)1, (ftnlen)
		6, (ftnlen)24);
    }
    if (*ifrm <= 0) {
	msgdmp_("E", "SLQRCT", "FRAME NUMBER IS LESS THAN ZERO.", (ftnlen)1, (
		ftnlen)6, (ftnlen)31);
    }
    jfrm = (*ifrm - 1) % slblk1_1.nn[*lev] + 1;
    nm = jfrm + isum0_(slblk1_1.nn, lev, &c__1);
    *xamin = slblk1_1.xmin[nm - 1];
    *xamax = slblk1_1.xmax[nm - 1];
    *yamin = slblk1_1.ymin[nm - 1];
    *yamax = slblk1_1.ymax[nm - 1];
    return 0;
} /* slqrct_ */
